API de Inventário de Peças do Revendedor
Começando
Conforme descrito na seção Compartilhamento de Dados , o DCP é totalmente voltado para dados. Uma parte importante dos dados é o inventário de Peças, Acessórios e Vestuário (PAA) do concessionário (abreviado para inventário de peças), usado em muitos programas de negócios da BRP.
Eles incluem, mas não se limitam a:
- O Gerenciamento de Inventário de Varejo é um programa de reposição automática.
- O Encontrar na Concessionária é um sistema que permite aos consumidores visualizar um amplo inventário de peças individuais de seu concessionário escolhido.
Observe que o compartilhamento do inventário de peças do concessionário agora está incluído no programa de certificação do concessionário: o concessionário perde pontos quando não compartilha seu inventário de peças.
Um dos objetivos é permitir que os concessionários compartilhem seus inventários de PAA diretamente de seus DMS, em vez de carregá-los manualmente pelo BOSSWeb.
A API de Inventário de Peças do Concessionário fornece dois serviços:
- Um serviço envolve receber o inventário do concessionário e atualizá-lo no sistema BRP.
- Um serviço para pesquisar um número de peça no inventário do concessionário (Concessionário-para-Concessionário).
Por Onde Começar? Leia Isto Primeiro!
Antes de começar a trabalhar nesta API, você precisa ler as seguintes seções se ainda não as tiver consultado:
Inventário de Peças do Concessionário
Seu DMS usa o serviço de inventário de peças para enviar o inventário do concessionário à BRP. As informações do inventário do concessionário devem ser atualizadas diariamente, mesmo que o concessionário esteja fechado.
Os dados do inventário do concessionário devem ser enviados fora do horário comercial para garantir que os valores mais recentes sejam enviados.
O concessionário deve consentir com o compartilhamento de dados antes que você envie o inventário de peças do concessionário para a BRP.
Seu DMS deve enviar apenas o inventário de peças de BRP Powersports concessionários que consentiram com o compartilhamento de dados.
Consulte a seção Compartilhamento de Dados para mais informações sobre compartilhamento de dados.
Localizador de Peças do Concessionário
O serviço de localizador de peças é usado para procurar uma peça no inventário de outro concessionário. A busca é limitada a uma distância do concessionário solicitante, com um valor padrão de 200 km e um máximo de 8.000 km.
O serviço permite que o concessionário encontre uma peça em outro concessionário que possa estar disponível mais rapidamente do que solicitar a peça da BRP, por exemplo, se a peça estiver em atraso.
Para pesquisar a disponibilidade e localização de peças no inventário da BRP, consulte a API de Inventário de Peças
Informações Técnicas
Características
Tipo de API | Tipo de DSP | Versão DCP | Complexidade |
|---|---|---|---|
Obter dados do BRP | DMS | V3 - Internacional | Baixa |
Enviar dados para o BRP | CRM | V4 - América do Norte | Um pouco mais |
Transação com BRP | | | Um pouco mais ainda |
Autenticação
A API está usando Autenticação da Aplicação.
Você precisa de um token de acesso válido antes de chamar esta API, ou deve chamar a API de Autenticação de Aplicativos para obter um.
O token de acesso é válido por 30 minutos! (1799 segundos)
URL Base
Teste | https://qa-cloud-api.brp.com/dcp/<v3 ou v4> |
|---|---|
Produção | https://cloud-api.brp.com/dcp/<v3 ou v4> |
Recurso: Inventário de Peças do Concessionário
Este recurso atualiza o inventário de peças do concessionário no sistema BRP.
Representação JSON
{
"dealer_no": "0000691756",
"inventory_date": "{{INVENTORY_DATE}}",
"parts_inventory": [
{
"product_code": "420430408",
"qty_on_hand": 15,
"qty_dealer_stocking": 10,
"qty_available": 7,
"qty_min_stocking_level": 2,
"qty_max_stocking_level": 12,
"qty_best_stocking_level": 8,
"last_physical_inventory_date": "2022-02-01"
},
{
"product_code": "705800048",
"qty_on_hand": 6,
"qty_dealer_stocking": 4,
"qty_available": 2,
"qty_min_stocking_level": 1,
"qty_max_stocking_level": 6,
"qty_best_stocking_level": 3,
"last_physical_inventory_date": "2022-03-01"
}
]
}
Propriedades
Propriedade | Tipo | Definição | Notas |
|---|---|---|---|
dealer_no * | string | Código que identifica exclusivamente um concessionário. Deve ter 10 caracteres. Se tiver menos de 10 caracteres, adicionar '0' no início. | Comprimento:10 |
inventory_date * | date-time | A data na qual a instância de inventário está sendo reportada pela fonte, no formato ISO 8601. | Formato: YYYY-MM-DDTHH:MM:SSZ |
* Esses campos são obrigatórios.
Recurso: Localizador de Peças do Concessionário
Este recurso é usado para localizar uma peça no inventário do concessionário.
Concessionárias com a peça solicitada disponível na quantidade requisitada são retornadas e classificadas por distância, da mais próxima para a mais distante.
Se a concessionária que está chamando o serviço Dealer Part Locator tiver a peça solicitada disponível na quantidade requisitada, a concessionária será a primeira retornada na lista de concessionárias com distância igual a 0.
Se a peça não for encontrada, uma lista vazia de concessionárias é retornada.
Representação JSON
{
"req_product_code": "204130096",
"req_qty": "5",
"dealers": [
{
"dealer_no": "0000700916",
"dealer_name": "PERFORMANCE NC - PRINCEVILLE",
"address": {
"street": "780 BL. BARIL OUEST (RTE 116)",
"city": "PRINCEVILLE",
"state": "QC",
"country": "CA",
"postal_code": "G6L 3W6"
},
"language": "FR",
"time_zone": "UTC-05000",
"phone_no": "819-505-0712",
"distance": 0
},
{
"dealer_no": "0000691731",
"dealer_name": "MERCIER MARINE LTEE",
"address": {
"street": "3670 BOUL. FRONTENAC OUEST",
"city": "THETFORD MINES",
"state": "QC",
"country": "CA",
"postal_code": "G6H 2B8"
},
"language": "FR",
"time_zone": "UTC-05000",
"phone_no": "418-423-5517",
"distance": 42.3
},
{
"dealer_no": "0000694650",
"dealer_name": "PERFORMANCE N.C. INC.",
"address": {
"street": "176 BOUL. INDUSTRIEL",
"city": "ST-GERMAIN DE GRANTHAM",
"state": "QC",
"country": "CA",
"postal_code": "J0C 1K0"
},
"language": "FR",
"time_zone": "UTC-05000",
"phone_no": "819-395-2464",
"distance": 84.2
}
]
}Propriedades
Property | Type | Definition | Notes |
|---|---|---|---|
req_product_code | string | Product code (same as part number) requested by the dealer | Max Length:18 |
req_qty | integer | The quantity requested by the dealer | Format: 999999 |
dealers | List of Objects | List of dealers who have the requested part in inventory |
|
dealers.dealer_no | string
| Dealer number. Must be 10 characters. If fewer than 10 characters, add '0' at the beginning. | Length:10 |
dealers.dealer_name | string | Dealer name | Max Length:80 |
dealers .address | Object | Address of the dealer |
|
dealers.address. street | string | Street address (1st line) | Max Length:60 |
dealers.address .city | strin | City Address | Max Length:40 |
dealers.address .state | string | Code that uniquely identifies a province/state in a country, in ISO 3166-2 (2nd part) format | Max Length:3 |
dealers.address .country | string | Code that uniquely identifies a country, in ISO 3166-1 format | Max Length:2 |
dealers.address .postal_code | string | Postal code of the dealer | Max Length:10 |
dealers.language | string | Communication language of the dealer in ISO language code (ISO-639-1 + ISO 3166-1) | Format xx-XX |
dealers.time_zone | string | Time zone corresponding to dealer’s region in ISO 8601. | Format: UTC±HH:MM |
dealers.phone_no | string | Dealer phone number | Max Length:16 |
dealers.distance | decimal
| The total distance between the origin and the dealership, based on the unit requested (km or mi). The calculation is made on driving distance if available, and crow-flight otherwise. | Format 99999.9 |
Limitações e Restrições
Concessionárias BRP Powersports e Consentimento para Compartilhamento de Dados
Seu DMS deve enviar apenas o inventário de peças de BRP Powersports concessionárias que consentiram com o compartilhamento de dados.
O inventário de peças enviado deve conter apenas peças BRP.
Tamanho do Payload
A API Dealer Parts Inventory é executada no APIGee, que possui um tamanho máximo de payload de 10 MB.
Como referência, o limite de 10 MB representa um máximo de 30.000 peças no payload se todos os campos opcionais forem enviados.
Veja a seção 413 Entidade da Requisição Muito Grande para mais informações sobre como lidar com o código de status 413.
👉 Para evitar problemas com o limite de tamanho de payload de 10 MB, a API Dealer Parts Inventory aceita no máximo 30.000 peças no seu payload.
Se o inventário do dealer contiver mais de 30.000 peças, você deve enviar quantos payloads de 30.000 peças forem necessários.
Valor Máximo de Contagem
Todas as quantidades de inventário das peças no payload têm um valor máximo de 999.999.
Alguns dealers estão usando um valor muito alto de quantity_on_hand em seu inventário para pequenas peças, como arruelas e parafusos, para evitar contá-las individualmente.
Para todos os valores de contagem superiores a 999.999, você deve arredondar o valor para 999.999 no payload.
Localizador de Peças do Dealer e Quantidade Disponível
O recurso Localizador de Peças do Distribuidor usa o valor de quantidade disponível em mãos para determinar se um distribuidor possui a peça solicitada em seu inventário.
Uma busca mais precisa utilizaria o quantidade disponível valor, que representa a quantidade que o distribuidor tem disponível para liberação do inventário. É tradicionalmente definida como quantidade em mãos menos peças reservadas ou comprometidas.
No entanto, o quantidade disponível é opcional no inventário de peças do distribuidor e atualmente não é uma fonte confiável de informação.
⛔ Número de Peça com '-'
Até o momento desta escrita, o Encontrar Peça (Localizador de Peças) serviço não pode ser usado com um número de peça que contenha um '-'.
O problema está na API de backend chamada pela API de Inventário de Peças do Distribuidor DCP. Não há previsão de correção no momento.
Por exemplo, a chamada:
GET https://cloud-api.brp.com/dcp/v4/part/3602-072/dealer-inventory?req_qty=1&dealer_no=0000708172
Retorna um status 400.
{
"status": 400,
"errors": [
{
"code": "invalid_query",
"title": "Invalid query parameters were specified",
"meta": [
{
"type": "field",
"value": "3602-072",
"msg": "product code must be alpha numeric",
"path": "product_code",
"location": "query"
}
]
}
]
}Referência da API
curl --location 'https://qa-cloud-api.brp.com/dcp/v3/parts/dealer-inventory' \
--header 'Dealer-Number: 0000691756' \
--header 'Content-Type: application/json' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' \
--data '{
"dealer_no": "0000691756",
"inventory_date": "{{INVENTORY_DATE}}",
"parts_inventory": [
{
"product_code": "779140",
"qty_on_hand": 773,
"qty_dealer_stocking": 947,
"qty_available": 831,
"qty_min_stocking_level": 780,{{INVENTORY_DATE}}
"qty_max_stocking_level": 145,
"qty_best_stocking_level": 156,
"last_physical_inventory_date": "2022-12-02"
}
]
}'curl --location 'https://qa-cloud-api.brp.com/dcp/v4/part/204130096/dealer-inventory?req_qty=1&dealer_no=0000700916&unit=mi&radius=23' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' \
Como Fazer
Esta seção fornece informações sobre como obter resultados específicos com a API.
Encontrar uma Peça no Inventário dos Concessionários
Procure um número de peça com 5 unidades disponíveis no inventário de peças dos concessionários usando o raio padrão de 200 km.
Neste exemplo, o concessionário que solicita a peça tem pelo menos 5 em seu inventário.
Há também outros 2 concessionários com pelo menos 5 peças disponíveis em seu inventário.
curl --location 'https://cloud-api.brp.com/dcp/v4/part/204130096/dealer-inventory?req_qty=5&dealer_no=0000700916' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Encontrar uma Peça em Concessionários Próximos
Procure um número de peça com 3 unidades disponíveis no inventário de peças dos concessionários em um raio de 80 km.
Neste exemplo, o revendedor que solicita a peça tem pelo menos 3 em seu inventário.
Há também outro revendedor com pelo menos 3 peças disponíveis em seu inventário.
curl --location 'https://cloud-api.brp.com/dcp/v4/part/204130096/dealer-inventory?req_qty=3&dealer_no=0000700916&unit=km&radius=80' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Peça Solicitada Não Encontrada
Procure um número de peça com 5 unidades disponíveis no inventário de peças dos concessionários dentro de um raio de 75 km. A lista de concessionários fica vazia se nenhum possuir a peça na quantidade solicitada.
curl --location 'https://cloud-api.brp.com/dcp/v4/part/12345678/dealer-inventory?req_qty=5&dealer_no=0000700916&unit=km&radius=75' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Tratamento de Erros
Esta seção apresenta vários cenários de chamadas inadequadas ou incorretas, que resultam em mensagens de erro e resultados inadequados.
Inventário de Peças do Concessionário
400 Solicitação Inválida
O código de status 400 é normalmente encontrado durante o desenvolvimento e a integração, e não deve ser recebido durante operações normais. A resposta retornada contém as informações necessárias para corrigir o problema.
Muitos problemas podem causar um código de status 400; os mais comuns estão listados na tabela abaixo.
Resposta | Resolução |
|---|---|
Retornado se o número do concessionário for inválido. {
"status": 400,
"id": "rrt-0570f...",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "O número do concessionário fornecido não existe ou é inválido."
}
} | Se o concessionário estiver usando seu DMS, pode ser porque ele não é mais um concessionário BRP. Verifique com ele e desative as atualizações de inventário de peças. Certifique-se de que o número do concessionário tenha 10 caracteres. Se você salvar o número do concessionário sem o '0' inicial, adicione o '0' antes de chamar a API. O erro também é retornado se o concessionário não for um concessionário BRP ativo. |
Retornado se a data do inventário tiver um formato inválido. {
"status": 400,
"id": "rrt-0570f8640a6...",
"title": "bad_request",
"meta": {
"service": "01",
"code": "request validation failed",
"errors": {
"details": [
{
"message": "[Path '/inventory_date'] String \"25-11-2023T15:18:58Z\" is invalid against requested date format(s) [yyyy-MM-dd'T'HH:mm:ssZ, yyyy-MM-dd'T'HH:mm:ss.[0-9]{1,12}Z]: []"
}
]
}
}
} | Altere o formato da string de data para corresponder ao formato do payload. |
Retornado se uma quantidade for maior que o limite. {
"status": 400,
"id": "rrt-0debaee1f7de5...",
"title": "bad_request",
"meta": {
"service": "01",
"code": "request validation failed",
"errors": {
"details": [
{
"message": "[Path '/parts_inventory/0/qty_on_hand'] Numeric instance is greater than the required maximum (maximum: 999999, found: 1000000): []"
}
]
}
}
} | Todas as quantidades no payload têm um valor máximo de 999.999. Se o seu DMS permitir um valor maior e o concessionário o utilizar, você deve arredondar o valor para 999.999 antes de enviar o inventário de peças. |
A lista de peças está vazia. {
"status": 400,
"id": "rrt-0cdea36b8097f17...",
"title": "bad_request",
"meta": {
"service": "07",
"payload": {
"errors": "Array 'parts_inventory' should not be empty."
}
}
} | O payload enviado contém uma lista de peças vazia. Ao aplicar os filtros definidos na seção Requisitos Funcionais não envie o inventário de peças se a lista estiver vazia. Em teoria, isso nunca deveria acontecer, pois significaria que todas as peças BRP têm uma quantity_on_hand de 0. |
Retornado se o payload contiver mais de 30.000 itens. {
"status": "400",
"id": "rrt-06c1b7ac7365beb8f-d-ea-22696-1347602-1",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "request validation failed",
"payload": {
"details": [
{
"message": "[Path '/parts_inventory'] Array is too long: must have at most 30000 elements but instance has 40000 elements: []"
}
]
}
}
} | Divida o inventário de peças para enviar vários payloads com no máximo 30.000 itens por payload. |
Este é um exemplo de uma chamada ao serviço de Inventário de Peças do Concessionário retornando um código de status 400 Bad Request.
curl --location 'https://qa-cloud-api.brp.com/dcp/v3/parts/dealer-inventory' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' \
--data '{
"dealer_no": "1234567890",
"inventory_date": "2022-11-23T15:18:58Z",
"parts_inventory": [
{
"product_code": "779140",
"qty_on_hand": 15,
"qty_dealer_stocking": 10,
"qty_available": 7,
"qty_min_stocking_level": 2,
"qty_max_stocking_level": 12,
"qty_best_stocking_level": 8,
"last_physical_inventory_date": "2022-02-01"
}
]
}'413 Entidade da Solicitação Muito Grande
O código de status 413 Request Entity Too Large é retornado quando o payload excede o limite de 10 MB do APIGee.
Observe que o código de status 413 pode ser recebido mesmo que o payload enviado tenha menos de 10 MB. O payload é processado e convertido antes de ser chamado por uma API interna do BRP, e essa API interna pode retornar um código de status 413.
Para corrigir o problema:
- Envie apenas as partes que têm um valor diferente de zero.
- Não as envie se o concessionário não estiver usando as propriedades opcionais, como qty_min_stocking_level.
401 Não autorizado
O código de status de erro 401 Unauthorized é retornado quando você tenta chamar a API Dealer Parts Inventory com um access_token expirado.
Você precisa obter um novo access_token com uma chamada para a API de Autenticação de Aplicação.
Localizador de Peças do Concessionário
400 Solicitação Inválida
O código de status 400 é normalmente encontrado durante o desenvolvimento e a integração, e não deve ser recebido durante operações normais. A resposta retornada contém as informações necessárias para corrigir o problema.
Muitos problemas podem causar um código de status 400; os mais comuns estão na tabela abaixo.
Resposta | Resolução |
|---|---|
O código do produto está ausente {
"status": 400,
"id": "rrt-0570f8640a6f6e...",
"title": "bad_request",
"meta": {
"service": "01",
"code": "request validation failed",
"errors": {
"details": [
{
"message": "O parâmetro de consulta 'sales_org' é obrigatório no caminho '/part/{part_number}', mas não foi encontrado na solicitação."
},
{
"message": "O parâmetro de consulta 'currency' é obrigatório no caminho '/part/{part_number}', mas não foi encontrado na solicitação."
},
{ | O número da peça (código do produto) está ausente na consulta. |
Número de revendedor inválido {
"status": 400,
"id": "rrt-0b8f470f8a6f5fd93-d-ea-19152-79657993-1.1",
"title": "not_found",
"meta": [
{
"service": "07",
"payload": {
"errors": {
"error_id": "4042",
"error_message": "O dealer_no é inválido"
}
}
}
]
} | Se o revendedor estiver usando seu DMS, pode ser porque ele não é mais um revendedor BRP. Verifique com ele e desative as atualizações de inventário de peças. Certifique-se de que o número do revendedor tenha 10 caracteres. Se você salvar o número do revendedor sem o '0' à esquerda, adicione o '0' antes de chamar a API. |
Código de produto (número da peça) inválido {
"status": 404,
"id": "rrt-0b8f470f8a6f...",
"title": "not_found",
"meta": [
{
"service": "07",
"payload": {
"errors": {
"error_id": "4043",
"error_message": "O product_no é inválido"
}
}
}
]
} | Todas as quantidades no payload têm um valor máximo de 999.999. Se o seu DMS permitir um valor maior e o revendedor utilizá-lo, você deve arredondar o valor para 999.999 antes de enviar o inventário de peças. |
401 Não autorizado
O código de status de erro 401 Não autorizado é retornado quando você tenta chamar a API com um access_token expirado.
Você precisa obter um novo access_token com uma chamada para a API de Autenticação de Aplicativos.
O código de status de erro 401 Unauthorized também é retornado se você não solicitou acesso à API criando um ticket no Jira do DCP.
Quando estiver pronto para começar a trabalhar em uma API, você deve criar um ticket de certificação no Jira, conforme descrito na seção Atividades de Certificação com o Jira.
Se você já começou a trabalhar em uma API e perdeu o acesso, crie um ticket de suporte conforme descrito na seção Abrir um Ticket de Suporte.
404 Não Encontrado
O código de status 404 Not Found é retornado apenas pela versão V3 se o número da peça for inválido.
No V4, uma lista vazia de revendedores é retornada quando o número da peça não é encontrado.
O código de status 404 Not Found é retornado quando a peça não é encontrada.
curl --location 'https://qa-cloud-api.brp.com/dcp/v3/part/123456789/dealer-inventory?req_qty=2&dealer_no=0000691737&unit=mi&radius=170.2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Correção
O concessionário pode ter inserido um número de peça inválido.
Requisitos DSP
Requisitos Funcionais
ID | Tipo | Requisito |
|---|---|---|
1 | Obrigatório | O inventário de peças do concessionário deve ser enviado automaticamente todos os dias, mesmo que o concessionário esteja fechado, fora do horário comercial do concessionário, para todos os concessionários que consentiram com o compartilhamento de dados. ❗ O inventário de peças do concessionário deve ser enviado automaticamente sem uma ação manual do concessionário ❗ |
2 | Obrigatório | Somente as peças BRP devem ser enviadas para o inventário do concessionário. Peças de outros OEMs e peças definidas pelo concessionário não devem ser enviadas. |
4 | Obrigatório | Para todos os valores superiores a 999.999, arredonde o valor para 999.999. |
5 | Obrigatório | Seu DMS deve enviar no máximo 30.000 peças em um payload. Se houver mais de 30.000 peças no inventário do concessionário, você deve enviar quantos payloads de 30.000 peças forem necessários. |
6 | Obrigatório | Somente o inventário de peças de concessionários BRP Powersports deve ser enviado quando o concessionário tiver consentido com o compartilhamento de dados. |
7 | Obrigatório | Se o concessionário remover o consentimento de compartilhamento de dados e deixar de ser um concessionário BRP, a transmissão dos dados de inventário de peças deve ser desativada. |
8 | Obrigatório | O Inventário de Peças do Concessionário deve ser chamado para enviar o inventário completo de peças do concessionário, NÃO uma peça por vez. |
Atividades de Certificação
Esta seção apresenta todas as atividades de certificação e validações que devem ser concluídas para certificar a API.
Garantia de Qualidade - POST
Os testes listados na tabela abaixo devem ser realizados com sucesso no ambiente de teste antes que você possa iniciar a fase piloto do revendedor.
ID | Teste | Resultado Esperado |
|---|---|---|
1 | Enviar o inventário de uma peça | O inventário foi recebido e não há erro no log da API. |
2 | Enviar um inventário completo do concessionário | O inventário foi recebido e não há erro no log da API. A equipe DCP verifica que o inventário de peças não contém peças que não sejam BRP. |
3 | Todo o inventário recebido | O inventário de peças é recebido para todos os concessionários que deram consentimento para compartilhar dados. |
4 | Inventário é atualizado | Verifique que o inventário do concessionário é atualizado, ou seja, a quantidade de algumas peças muda ao longo do tempo. |
5 | Enviar o inventário com dados divididos | Verifique que múltiplos payloads são enviados se o inventário do concessionário exceder 30.000 peças. 👉 Se o inventário do concessionário usado para teste tiver menos de 30.000 peças, você deve alterar o limite no seu DMS para enviar pelo menos 2 payloads. |
6 | Atualizações automatizadas | Verifique que o inventário é enviado automaticamente diariamente por 5 dias consecutivos. |
Garantia de Qualidade - GET
Os testes listados na tabela abaixo devem ser concluídos no ambiente de teste antes que você possa iniciar a fase piloto do revendedor.
ID | Teste | Resultado Esperado |
|---|---|---|
1 | Pesquisar pela peça 517308658 sem raio e com quantidade 1 | Uma lista de concessionárias deve ser encontrada. |
2 | Pesquisar pela peça 517308658 com raio de 100 mi ou km e quantidade 10 | Uma lista de concessionárias deve ser encontrada. |
3 | Pesquisar pela peça 517308658 com raio de 15000 mi ou km e quantidade 3 | Uma lista de concessionárias deve ser encontrada. |
4 | Pesquisar pela peça 219400698 com raio de 75 mi ou km e quantidade 5 | A lista de concessionárias deve estar vazia. |
Os seguintes números de peça estão disponíveis para teste:
- 715005683
- 517308658
- 219906024
- 706203893
- 224081201
- 9779126
- S40100RCA000
Piloto do Concessionário
A tabela abaixo descreve os parâmetros do piloto do concessionário e suas validações correspondentes.
Parâmetro | Valor |
|---|---|
Ambiente | Produção |
Número de concessionárias | 1 a 3 |
Duração | 1 semana |
Validação 1 | A equipe DCP verifica que o inventário de peças das concessionárias é recebido diariamente. |
Validação 2 | A equipe DCP verifica que o inventário de peças das concessionárias não contém peças que não sejam da BRP. |
Validação 3 | Para cada concessionária no piloto, você exporta o inventário da concessionária para um arquivo Excel, CSV ou JSON por 5 dias (os dias não precisam ser consecutivos). A equipe DCP valida que o inventário recebido corresponde ao inventário nos arquivos exportados. |
Validação 4 | A equipe DCP verifica que não há erro no log da API. |
Validação 5 | Enviar capturas de tela dos resultados de busca do localizador de peças. Uma peça pesquisada para cada linha de produto suportada pela concessionária, para cada concessionária. |
Postman
Esta seção descreve o que está disponível no Postman para explorar a API.
Ambientes
Um ambiente Postman está disponível para testar a API de Inventário de Peças do Revendedor. Este ambiente Postman contém variáveis que as consultas utilizam e está configurado para se conectar ao ambiente de teste.
Coleções
A coleção DMS - Inventário de Peças do Revendedor inclui exemplos de chamadas de API para atualizar o inventário de peças de um revendedor e pesquisar uma peça nele.